==> visier_api_data_in-0.99201.1656-py3-none-any.whl: visier_api_data_in/models/plan_data_load_change_dto.py <==
# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1656
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PlanDataLoadChangeDTO(BaseModel):
    """
    PlanDataLoadChangeDTO
    """ # noqa: E501
    new_value: Optional[StrictInt] = Field(default=None, description="The new value loaded into the plan from the data load.", alias="newValue")
    old_value: Optional[StrictInt] = Field(default=None, description="The value that was replaced.", alias="oldValue")
    period: Optional[StrictStr] = Field(default=None, description="The display name of the time period.")
    row_members: Optional[List[StrictStr]] = Field(default=None, description="The collection of member ids that describe the row in the plan.", alias="rowMembers")
    __properties: ClassVar[List[str]] = ["newValue", "oldValue", "period", "rowMembers"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PlanDataLoadChangeDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PlanDataLoadChangeDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "newValue": obj.get("newValue"),
            "oldValue": obj.get("oldValue"),
            "period": obj.get("period"),
            "rowMembers": obj.get("rowMembers")
        })
        return _obj

==> visier_api_data_in-0.99201.1701-py3-none-any.whl: visier_api_data_in/models/plan_data_load_change_dto.py <==
# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1701
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class PlanDataLoadChangeDTO(BaseModel):
    """
    PlanDataLoadChangeDTO
    """ # noqa: E501
    new_value: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The new value loaded into the plan from the data load.", alias="newValue")
    old_value: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The value that was replaced.", alias="oldValue")
    period: Optional[StrictStr] = Field(default=None, description="The display name of the time period.")
    row_members: Optional[List[StrictStr]] = Field(default=None, description="The collection of member ids that describe the row in the plan.", alias="rowMembers")
    __properties: ClassVar[List[str]] = ["newValue", "oldValue", "period", "rowMembers"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PlanDataLoadChangeDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PlanDataLoadChangeDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "newValue": obj.get("newValue"),
            "oldValue": obj.get("oldValue"),
            "period": obj.get("period"),
            "rowMembers": obj.get("rowMembers")
        })
        return _obj
